# btcoreutil

Utility library for Bitcoin Core.

## Table of Contents

- [Install](#install)
- [License](#license)

## <div id="install">Install</div>

```
pip install btcoreutil
```

## <div id="license">License</div>

Distributed under the MIT License. See the accompanying file LICENSE.
